@@ -19,7 +19,9 @@ def get_github_compare_url(from_version: str, to_version: str) -> str:
     )
 
 
-def compare_url(version: str, previous_version: str = None, **kwargs) -> Optional[str]:
+def compare_url(
+    version: str, previous_version: Optional[str] = None, **kwargs
+) -> Optional[str]:
     if config.get("hvcs").lower() == "github" and previous_version:
         compare_url = get_github_compare_url(previous_version, version)
         return f"**[See all commits in this version]({compare_url})**"
