@@ -17,8 +17,11 @@ from .helpers import LoggedFunction
 from .settings import config
 
 _repo: Optional[Repo]
+_sub_directory = ""
 try:
     _repo = Repo(".", search_parent_directories=True)
+    if config.get("use_only_cwd_commits") and config.get("version_source") == "commit":
+        _sub_directory = os.path.relpath(os.getcwd(), _repo.working_dir)
 except InvalidGitRepositoryError:
     _repo = None
 
@@ -79,7 +82,7 @@ def get_commit_log(from_rev=None, to_rev=None):
     elif to_rev:
         rev = f"{to_rev}..."
 
-    for commit in repo().iter_commits(rev):
+    for commit in repo().iter_commits(rev, paths=_sub_directory):
         yield (commit.hexsha, commit.message.replace("\r\n", "\n"))
 
 
@@ -179,11 +182,11 @@ def update_changelog_file(version: str, content_to_add: str):
     changelog_file = config.get("changelog_file")
     changelog_placeholder = config.get("changelog_placeholder")
     git_path = Path(os.getcwd(), changelog_file)
-    if not git_path.exists() or git_path.read_text().strip() == "":
+    if not git_path.exists() or git_path.read_text(encoding="utf-8").strip() == "":
         original_content = f"# Changelog\n\n{changelog_placeholder}\n"
         logger.warning(f"Changelog file not found: {git_path} - creating it.")
     else:
-        original_content = git_path.read_text()
+        original_content = git_path.read_text(encoding="utf-8")
     if (
         changelog_placeholder not in original_content
         and "# Changelog" in original_content
@@ -205,7 +208,7 @@ def update_changelog_file(version: str, content_to_add: str):
             [
                 changelog_placeholder,
                 "",
-                f"## v{version} ({date.today():%Y-%m-%d})",
+                f"## v{version} ({date.today():%Y-%m-%d})\n",
                 content_to_add,
             ]
         ),
